/**********************************************************************
* This is a Synthetic VIX indicator as described in the December 2007 *
* issue of "Active Trader" magazine.  The indicator is also named the *
* "Williams VIX Fix" since Larry Williams is credited with the        *
* formula's discovery.                                                *
*                                                                     *
* This indicator was coded by Matthew Ebersviller.   
 and modified by sohocool the 07/01/2011                 
 Kalenzo (bartlomiej.gorski@gmail.com) added bolinger band to this 
 indicator
 
**********************************************************************/


#property copyright "Copyright  2007, Matthew Ebersviller - mod by Kalenzo"
#property link      "mod: bartlomiej.gorski@gmail.com"

#property indicator_separate_window
#property indicator_buffers 3
#property indicator_color1 DodgerBlue
#property indicator_width1 1
#property indicator_color2 Red
#property indicator_width2 1
#property indicator_color3 Lime
#property indicator_width3 1

extern int    VIX_Period      = 22;
extern int    BandsPeriod     = 20, 
              BandsDeviation  = 2, 
              BandsShift      = 0;
extern bool   alertsOn        = true;
extern bool   alertsOnCurrent = true;
extern bool   alertsMessage   = true;
extern bool   alertsSound     = false;
extern bool   alertsNotify    = true;
extern bool   alertsEmail     = true;
extern string soundFile       = "alert2.wav"; 

double VixBuffer[];
double up[],dn[],trend[];

int init() {
   string short_name;
   IndicatorBuffers(4);
   
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,VixBuffer);
   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,up);
   SetIndexStyle(2,DRAW_LINE);
   SetIndexBuffer(2,dn);
   SetIndexBuffer(3,trend);
   //SetIndexBuffer(1,TempBuffer);
   short_name="KALE_VIX("+VIX_Period+")";
   IndicatorShortName(short_name);
   SetIndexLabel(0,short_name);

   SetIndexDrawBegin(0,VIX_Period);
   
   return(0);
}

int deinit()
  {
   return(0);
  }

int start()
{
   int counted_bars=IndicatorCounted();

   if(counted_bars<0) return(-1);
   if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
      
      
   for(int i=limit; i>=0; i--) 
   {
      VixBuffer[i] = VIX(i);
      up[i] = iBandsOnArray(VixBuffer, 0, BandsPeriod, BandsDeviation, BandsShift, MODE_UPPER, i);    
      dn[i] = iBandsOnArray(VixBuffer, 0, BandsPeriod, BandsDeviation, BandsShift, MODE_LOWER, i); 
      trend[i] = trend[i+1];
         if (VixBuffer[i]<dn[i]) trend[i] = 1;
         if (VixBuffer[i]>up[i]) trend[i] =-1;  
   }
   
   //
   //
   //
   //
   //
      
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      if (trend[whichBar] != trend[whichBar+1])
      if (trend[whichBar] == 1)
            doAlert("Buy");
      else  doAlert("Sell");       
   }   
   return(0);
  }
//+------------------------------------------------------------------+

double VIX(int shift) {
  double highClose, vix;
  highClose = High[iHighest(NULL,0,MODE_CLOSE,VIX_Period,shift)];
  vix = -100 *(highClose - Low[shift]) / highClose ;
  return (vix);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," Kale_Synthe_VIX ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(StringConcatenate(Symbol(), Period() ," Kale_Synthe_VIX " +" "+message));
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," Kale_Synthe_VIX "),message);
             if (alertsSound)   PlaySound(soundFile);
      }
}
  